@@ -22,7 +22,6 @@ package havener
 
 import (
 	"fmt"
-	"io/ioutil"
 	"os"
 	"path/filepath"
 	"strings"
@@ -39,16 +38,22 @@ import (
 	"k8s.io/client-go/rest"
 	"k8s.io/client-go/tools/clientcmd"
 
-	"github.com/gonvenience/wrap"
 	"gopkg.in/yaml.v3"
 )
 
-// KubeConfigDefault returns assumed default locaation of the Kubernetes
-// configuration, which is expected to be `$HOME/.kube/config`.
-func KubeConfigDefault() (string, error) {
+// KubeConfig returns the path to the Kubernetes configuration,
+// this is either whatever is set in KUBECONFIG,
+// or the well known default location `$HOME/.kube/config`
+func KubeConfig() (string, error) {
+	// In case `KUBECONFIG` environment variable is set, this will take precedence
+	if value, ok := os.LookupEnv("KUBECONFIG"); ok {
+		return value, nil
+	}
+
+	// Otherwise, default to the well known location
 	home, err := os.UserHomeDir()
 	if err != nil {
-		return "", wrap.Error(err, "unable to get home directory")
+		return "", fmt.Errorf("unable to get home directory: %w", err)
 	}
 
 	return filepath.Join(home, ".kube", "config"), nil
@@ -60,7 +65,12 @@ func outOfClusterAuthentication(kubeConfig string) (*kubernetes.Clientset, *rest
 		return nil, nil, fmt.Errorf("no kube config supplied")
 	}
 
-	logf(Verbose, "Connecting to Kubernetes cluster...")
+	clusterName, err := clusterName(kubeConfig)
+	if err != nil {
+		return nil, nil, fmt.Errorf("failed to look-up cluster name: %w", err)
+	}
+
+	logf(Verbose, "Connecting to Kubernetes cluster _%s_ ...", clusterName)
 
 	// BuildConfigFromFlags is a helper function that builds configs from a master
 	// url or a kubeconfig filepath.
@@ -76,17 +86,8 @@ func outOfClusterAuthentication(kubeConfig string) (*kubernetes.Clientset, *rest
 	return clientset, config, err
 }
 
-func isSystemNamespace(namespace string) bool {
-	switch namespace {
-	case "default", "kube-system", "ibm-system":
-		return true
-	}
-
-	return false
-}
-
 func clusterName(kubeConfig string) (string, error) {
-	data, err := ioutil.ReadFile(kubeConfig)
+	data, err := os.ReadFile(kubeConfig)
 	if err != nil {
 		return "", err
 	}
